@@ -24,13 +24,11 @@ import logging
 import sys
 
 from keystoneclient.v2_0 import client as ksclient
-import six
 
 import monascaclient
 from monascaclient import client as monasca_client
 from monascaclient.common import utils
 from monascaclient import exc
-from monascaclient.openstack.common import strutils
 
 
 logger = logging.getLogger(__name__)
@@ -48,7 +46,7 @@ class MonascaShell(object):
             # formatter_class=HelpFormatter,
             formatter_class=lambda prog: argparse.HelpFormatter(
                 prog,
-                max_help_position=25)
+                max_help_position=29)
         )
 
         # Global arguments
@@ -268,7 +266,7 @@ class MonascaShell(object):
                 filter_value=kwargs.get('region_name'),
                 endpoint_type=kwargs.get('endpoint_type') or 'publicURL')
         return client.service_catalog.url_for(
-            service_type=kwargs.get('service_type') or 'orchestration',
+            service_type=kwargs.get('service_type') or 'monitoring',
             endpoint_type=kwargs.get('endpoint_type') or 'publicURL')
 
     def _setup_logging(self, debug):
@@ -355,8 +353,6 @@ class MonascaShell(object):
         }
 
         endpoint = args.monasca_api_url
-        if endpoint.endswith('/'):
-            endpoint = endpoint[:-1]
 
         if not args.os_no_client_auth:
             _ksclient = self._get_ksclient(**kwargs)
@@ -432,7 +428,7 @@ def main(args=None):
         if '--debug' in args or '-d' in args:
             raise
         else:
-            print(strutils.safe_encode(six.text_type(e)), file=sys.stderr)
+            print(e, file=sys.stderr)
         sys.exit(1)
 
 if __name__ == "__main__":
